@@ -859,10 +859,13 @@ class Field(object):
         if self.get_type() == 'manytoone':
             options.append(("None", "", True))
         user_defined_options = self._config.options
-        if user_defined_options:
+        if isinstance(user_defined_options, list) and len(user_defined_options) > 0:
             for option in user_defined_options:
                 # TODO: Filter user defined options too (ti) <2014-02-19 23:46>
                 options.append((option[0], option[1], True))
+        elif isinstance(user_defined_options, str):
+            for option in self._form.merged_data.get(user_defined_options):
+                options.append((option[0], option[1], True))
         elif self._form._dbsession:
             options.extend(self.filter_options(self._load_options_from_db()))
         else:
